
************************
CFEI Python sMAP Library
************************


Python library for querying sMAP servers to fetch data, subscribing to receive real-time updates, and posting new data.


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   library
   reference
   timezones
   internals


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
